/********************************************************************************
** Form generated from reading UI file 'newGameDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWGAMEDIALOG_H
#define UI_NEWGAMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "minimapview.h"

QT_BEGIN_NAMESPACE

class Ui_newGameDialog
{
public:
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QTreeView *playerList;
    QPushButton *addPlayerButton;
    QPushButton *removePlayerButton;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QSpinBox *neutralPlanetsSB;
    QLabel *label_3;
    QSpinBox *widthSB;
    QLabel *label_4;
    QSpinBox *heightSB;
    MiniMapView *map;
    QLabel *label_6;
    QSpinBox *ProductionSB;
    QDoubleSpinBox *KillPercentageSB;
    QLabel *label_5;
    QPushButton *randomizeMap;
    QLabel *label;
    QComboBox *OwnerCB;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout;
    QCheckBox *BlindMapCB;
    QCheckBox *CumulativeProductionCB;
    QCheckBox *ProductionAfterConquereCB;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout_3;
    QCheckBox *NeutralsShowShipsCB;
    QCheckBox *NeutralsShowStatsCB;
    QLabel *label_7;
    QSpinBox *NeutralsProductionSB;

    void setupUi(QWidget *newGameDialog)
    {
        if (newGameDialog->objectName().isEmpty())
            newGameDialog->setObjectName("newGameDialog");
        newGameDialog->resize(857, 329);
        horizontalLayout = new QHBoxLayout(newGameDialog);
        horizontalLayout->setObjectName("horizontalLayout");
        groupBox_2 = new QGroupBox(newGameDialog);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        playerList = new QTreeView(groupBox_2);
        playerList->setObjectName("playerList");
        playerList->setRootIsDecorated(false);
        playerList->setUniformRowHeights(true);
        playerList->setItemsExpandable(false);

        gridLayout_2->addWidget(playerList, 0, 0, 1, 2);

        addPlayerButton = new QPushButton(groupBox_2);
        addPlayerButton->setObjectName("addPlayerButton");

        gridLayout_2->addWidget(addPlayerButton, 1, 0, 1, 1);

        removePlayerButton = new QPushButton(groupBox_2);
        removePlayerButton->setObjectName("removePlayerButton");

        gridLayout_2->addWidget(removePlayerButton, 1, 1, 1, 1);


        horizontalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(newGameDialog);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        neutralPlanetsSB = new QSpinBox(groupBox);
        neutralPlanetsSB->setObjectName("neutralPlanetsSB");
        neutralPlanetsSB->setMinimum(0);
        neutralPlanetsSB->setMaximum(90);
        neutralPlanetsSB->setValue(5);

        gridLayout->addWidget(neutralPlanetsSB, 0, 2, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        widthSB = new QSpinBox(groupBox);
        widthSB->setObjectName("widthSB");
        widthSB->setMinimum(4);
        widthSB->setMaximum(30);
        widthSB->setValue(16);

        gridLayout->addWidget(widthSB, 1, 2, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        heightSB = new QSpinBox(groupBox);
        heightSB->setObjectName("heightSB");
        heightSB->setMinimum(4);
        heightSB->setMaximum(30);
        heightSB->setValue(16);

        gridLayout->addWidget(heightSB, 2, 2, 1, 1);

        map = new MiniMapView(groupBox);
        map->setObjectName("map");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(map->sizePolicy().hasHeightForWidth());
        map->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(map, 3, 0, 2, 3);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 7, 0, 1, 1);

        ProductionSB = new QSpinBox(groupBox);
        ProductionSB->setObjectName("ProductionSB");
        ProductionSB->setMinimum(-100);
        ProductionSB->setMaximum(100);
        ProductionSB->setValue(10);

        gridLayout->addWidget(ProductionSB, 7, 2, 1, 1);

        KillPercentageSB = new QDoubleSpinBox(groupBox);
        KillPercentageSB->setObjectName("KillPercentageSB");
        KillPercentageSB->setDecimals(3);
        KillPercentageSB->setMaximum(1.000000000000000);
        KillPercentageSB->setSingleStep(0.050000000000000);
        KillPercentageSB->setValue(0.400000000000000);

        gridLayout->addWidget(KillPercentageSB, 6, 2, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 6, 0, 1, 1);

        randomizeMap = new QPushButton(groupBox);
        randomizeMap->setObjectName("randomizeMap");

        gridLayout->addWidget(randomizeMap, 8, 0, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 5, 0, 1, 1);

        OwnerCB = new QComboBox(groupBox);
        OwnerCB->setObjectName("OwnerCB");

        gridLayout->addWidget(OwnerCB, 5, 2, 1, 1);


        horizontalLayout->addWidget(groupBox);

        groupBox_3 = new QGroupBox(newGameDialog);
        groupBox_3->setObjectName("groupBox_3");
        sizePolicy1.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(groupBox_3);
        verticalLayout->setObjectName("verticalLayout");
        BlindMapCB = new QCheckBox(groupBox_3);
        BlindMapCB->setObjectName("BlindMapCB");

        verticalLayout->addWidget(BlindMapCB);

        CumulativeProductionCB = new QCheckBox(groupBox_3);
        CumulativeProductionCB->setObjectName("CumulativeProductionCB");

        verticalLayout->addWidget(CumulativeProductionCB);

        ProductionAfterConquereCB = new QCheckBox(groupBox_3);
        ProductionAfterConquereCB->setObjectName("ProductionAfterConquereCB");
        ProductionAfterConquereCB->setChecked(true);

        verticalLayout->addWidget(ProductionAfterConquereCB);

        groupBox_4 = new QGroupBox(groupBox_3);
        groupBox_4->setObjectName("groupBox_4");
        groupBox_4->setFlat(false);
        groupBox_4->setCheckable(false);
        groupBox_4->setChecked(false);
        gridLayout_3 = new QGridLayout(groupBox_4);
        gridLayout_3->setObjectName("gridLayout_3");
        NeutralsShowShipsCB = new QCheckBox(groupBox_4);
        NeutralsShowShipsCB->setObjectName("NeutralsShowShipsCB");

        gridLayout_3->addWidget(NeutralsShowShipsCB, 0, 0, 1, 2);

        NeutralsShowStatsCB = new QCheckBox(groupBox_4);
        NeutralsShowStatsCB->setObjectName("NeutralsShowStatsCB");

        gridLayout_3->addWidget(NeutralsShowStatsCB, 1, 0, 1, 2);

        label_7 = new QLabel(groupBox_4);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 2, 0, 1, 1);

        NeutralsProductionSB = new QSpinBox(groupBox_4);
        NeutralsProductionSB->setObjectName("NeutralsProductionSB");
        NeutralsProductionSB->setMaximum(100);
        NeutralsProductionSB->setValue(1);

        gridLayout_3->addWidget(NeutralsProductionSB, 2, 1, 1, 1);


        verticalLayout->addWidget(groupBox_4);


        horizontalLayout->addWidget(groupBox_3);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(neutralPlanetsSB);
        label_3->setBuddy(widthSB);
        label_4->setBuddy(heightSB);
        label_6->setBuddy(neutralPlanetsSB);
        label_5->setBuddy(neutralPlanetsSB);
#endif // QT_CONFIG(shortcut)

        retranslateUi(newGameDialog);

        QMetaObject::connectSlotsByName(newGameDialog);
    } // setupUi

    void retranslateUi(QWidget *newGameDialog)
    {
        newGameDialog->setWindowTitle(tr2i18n("Dialog", nullptr));
        groupBox_2->setTitle(tr2i18n("Players", nullptr));
        addPlayerButton->setText(tr2i18n("&Add", nullptr));
        removePlayerButton->setText(tr2i18n("&Remove", nullptr));
        groupBox->setTitle(tr2i18n("Map", nullptr));
        label_2->setText(tr2i18n("&Neutral planets:", nullptr));
        label_3->setText(tr2i18n("&Width:", nullptr));
        label_4->setText(tr2i18n("&Height:", nullptr));
        label_6->setText(tr2i18n("Production:", nullptr));
        label_5->setText(tr2i18n("Kill percentage:", nullptr));
        randomizeMap->setText(tr2i18n("&Randomize", nullptr));
        label->setText(tr2i18n("Owner:", nullptr));
        groupBox_3->setTitle(tr2i18n("Options", nullptr));
        BlindMapCB->setText(tr2i18n("Blind map", nullptr));
        CumulativeProductionCB->setText(tr2i18n("Cumulative production", nullptr));
        ProductionAfterConquereCB->setText(tr2i18n("Production after capture", nullptr));
        groupBox_4->setTitle(tr2i18n("Neutrals", nullptr));
        NeutralsShowShipsCB->setText(tr2i18n("Show ships", nullptr));
        NeutralsShowStatsCB->setText(tr2i18n("Show stats", nullptr));
        label_7->setText(tr2i18n("Production:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class newGameDialog: public Ui_newGameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWGAMEDIALOG_H

